@@ -12,7 +12,7 @@ ngram_vars={
     "nlp":"",
     "matcher":""
 }
-plt.rcParams['figure.figsize'] = [6, 8]
+plt.rcParams['figure.figsize'] = [8, 6]
 def setup():
     global ngram_vars
     ngram_vars["nlp"] = LOAD('es_core_news_md', disable=['parser','ner','textcat','...'] )
@@ -131,6 +131,7 @@ def calculateDist(dataset,group_by="month"):
     return pySophia2WordDistribution
 
 def view(word_distribution, words, annotate=False, normalize=True): 
+    fig, ax = plt.subplots()
     """Graph the frecuency term for a set of words, it could be normalized by the news in each period, or calculated in total times appearances.
     
      Args:
@@ -154,16 +155,15 @@ def view(word_distribution, words, annotate=False, normalize=True):
             for key in word_distribution:
                 keys.append(key)
                 ngram_dictionary[palabra].append(word_distribution[key]["dictionary"][palabra])
-        plt.plot(keys,ngram_dictionary[palabra],label=palabra)
-        plt.legend(loc=5, bbox_to_anchor=(1.3, 0.5), fancybox=True, shadow=True )
-        plt.title("PySophia2 NGramViewer")
+        ax.plot(keys,ngram_dictionary[palabra],label=palabra)
+        ax.legend(loc=5, bbox_to_anchor=(1.3, 0.5), fancybox=True, shadow=True )
+        ax.set_title("PySophia2 NGramViewer")
         if(annotate):
             for xy in zip(keys, ngram_dictionary[palabra]):                               
-                plt.annotate(('%.2f' % xy[1]), xy=xy, textcoords='data')
-    plt.xlabel('Date', fontsize=12)
-    plt.ylabel('Frequency', fontsize=12)
+                ax.annotate(('%.2f' % xy[1]), xy=xy, textcoords='data')
+    ax.set_xlabel('Date', fontsize=12)
+    ax.set_ylabel('Frequency', fontsize=12)
     plt.xticks(rotation=90)
-    plt.rcParams['figure.figsize'] = [7, 7]
     
     
 def freq(word_distribution,top_n=None, words=None, graph=True):
@@ -195,7 +195,8 @@ def freq(word_distribution,top_n=None, words=None, graph=True):
             x = [x[0] for x in top]
             y = [x[1]/total_news for x in top]
             ax.bar(x,y)
-            ax.title("Term frecuency top %i words" %(top_n))
+            ax.set_title("Term frecuency top %i words" %(top_n))
+            plt.xticks(rotation=90)
         return top
     elif words!=None:
         y = []
@@ -204,7 +205,7 @@ def freq(word_distribution,top_n=None, words=None, graph=True):
         ax.bar(words,y)
         ax.set_title("Term frecuency bar graph")
         ax.set_ylabel('Frequency', fontsize=12)
-        ax.set_xticks(rotation=90)
+        plt.xticks(rotation=90)
         
         
 
